@@ -14,7 +14,7 @@ pub fn connect_key() -> String {
     base64::encode(&buf)
 }
 
-pub fn connect_header(host: &str, path: &str, key: &str, headers: Option<HashMap<String, String>>) -> String {
+pub fn connect_header(host: &str, path: &str, key: &str, headers: &HashMap<String, String>) -> String {
     let mut h = "GET ".to_owned()
         + path
         + " HTTP/1.1\r\n\
@@ -28,13 +28,11 @@ Sec-WebSocket-Key: ";
     h.push_str("Host: ");
     h.push_str(host);
     h.push_str("\r\n");
-    if let Some(headers) = headers {
-        for (key, value) in headers.iter() {
-            h.push_str(key);
-            h.push_str(": ");
-            h.push_str(value);
-            h.push_str("\r\n");
-        }
+    for (key, value) in headers.iter() {
+        h.push_str(key);
+        h.push_str(": ");
+        h.push_str(value);
+        h.push_str("\r\n");
     }
     h.push_str("\r\n");
     // println!("send {}", h);
@@ -47,7 +45,7 @@ Sec-WebSocket-Key: ";
 pub async fn connect_http<R, W>(
     mut stream_rh: R, mut stream_wh: W,
     url: &Url,
-    headers: Option<HashMap<String, String>>,
+    headers: &HashMap<String, String>,
 ) -> Result<(tokio::io::BufReader<R>, W, bool, HashMap<String, String>), tokio::io::Error>
     where
         R: AsyncReadExt + std::marker::Unpin,
@@ -78,7 +76,7 @@ pub async fn connect_http<R, W>(
             _n => {
                 // println!("{}", line);
                 lines.push(line.trim().to_owned())
-            },
+            }
         }
     }
 
@@ -204,6 +202,7 @@ fn ws_accept(key: &str) -> String {
     base64::encode(&hr)
 }
 
+#[derive(Clone)]
 pub struct Url {
     pub addr: String,
     pub path: String,
