@@ -13,9 +13,9 @@ async fn main() -> Result<(), Error> {
     builder.filter_level(LevelFilter::Trace);
     builder.init();
 
-    // let client = Client::new("wss://sfstream.binance.com/stream?streams=btcusdt@trade", true);
+    let mut client = Client::new("wss://sfstream.binance.com/stream?streams=btcusdt@trade", true);
     // let client = Client::new("wss://sfstream.binance.com/stream", true);
-    let mut client = Client::new("ws://127.0.0.1:3012/", true);
+    // let mut client = Client::new("ws://127.0.0.1:3012/", true);
 
 
     let msg = "{\"method\": \"SUBSCRIBE\",\"params\":[\"btcusdt@aggTrade\",\"btcusdt@depth\"],\"id\": 1}";
@@ -25,7 +25,8 @@ async fn main() -> Result<(), Error> {
     let vec1 = vec![Msg::Text(msg.to_string().into_bytes()), Msg::Text(msg2.to_string().into_bytes())];
     client.auto_reconnect(vec1, tokio::time::Duration::from_millis(3000));
 
-    let mut socket = client.connect2().await?;
+    // let mut socket = client.connect2().await?;
+    let mut socket = client.connect_empty().await?;
 
 
     // let _ = socket.send(Msg::Text(msg.to_string().into_bytes())).await;
