@@ -16,7 +16,6 @@ pub enum Msg {
     Close(u16),
     Ping(Vec<u8>),
     Pong(Vec<u8>),
-    Clear(),
 }
 
 
@@ -37,7 +36,6 @@ impl Msg {
             Msg::Close(_) => "close",
             Msg::Ping(_) => "ping",
             Msg::Pong(_) => "pong",
-            Msg::Clear() => "clear",
         }
     }
 }
@@ -486,7 +484,7 @@ impl<W> Writer<W>
         let mut buf = raw.as_slice();
 
         loop {
-            let len = self.stream_tx.write(buf).await.unwrap();
+            let len = self.stream_tx.write(buf).await?;
             // println!("write len {}", len);
             if len == buf.len() {
                 break;
